@@ -1,6 +1,6 @@
 package SPVM;
 
-our $VERSION = '0.9662_02';
+our $VERSION = '0.961101_01';
 
 use 5.008007;
 use strict;
@@ -78,54 +78,42 @@ sub import {
       next if $added_class_name =~ /::anon/;
       
       # Build Precompile classs - Compile C source codes and link them to SPVM precompile method
-      $BUILDER->build_and_bind_dynamic_lib_at_runtime($added_class_name, 'precompile');
+      $BUILDER->build_and_bind_dynamic_lib($added_class_name, 'precompile');
       
       # Build native classs - Compile C source codes and link them to SPVM native method
-      $BUILDER->build_and_bind_dynamic_lib_at_runtime($added_class_name, 'native');
+      $BUILDER->build_and_bind_dynamic_lib($added_class_name, 'native');
     }
   }
 }
 
 sub init {
   unless ($SPVM_INITED) {
-    unless ($BUILDER) {
-      # If any SPVM module are not yet loaded, $BUILDER is not set.
-      my $build_dir = $ENV{SPVM_BUILD_DIR};
-      $BUILDER = SPVM::Builder->new(build_dir => $build_dir, include_dirs => [@INC]);
-      my $compile_success = $BUILDER->compile_spvm('Int', 'embedded://none', 0);
-      unless ($compile_success) {
-        confess "Unexpcted Error:the compiliation must be always successful";
-      }
-      $BUILDER->build_runtime;
-    }
-    
-    # Prepare runtime environment
-    $BUILDER->prepare_env;
+    if (my $builder = $BUILDER) {
+      
+      # Prepare runtime environment
+      $builder->prepare_env;
 
-    # Set native method addresses
-    for my $class_name (keys %{$BUILDER->native_address_info}) {
-      my $address_of_methods = $BUILDER->native_address_info->{$class_name};
-      for my $method_name (keys %$address_of_methods) {
-        my $address = $address_of_methods->{$method_name};
-        $BUILDER->set_native_method_address($class_name, $method_name, $address);
+      # Set native method addresses
+      for my $class_name (keys %{$builder->native_address_info}) {
+        my $address_of_methods = $builder->native_address_info->{$class_name};
+        for my $method_name (keys %$address_of_methods) {
+          my $address = $address_of_methods->{$method_name};
+          $builder->set_native_method_address($class_name, $method_name, $address);
+        }
       }
-    }
 
-    # Set precompile method addresses
-    for my $class_name (keys %{$BUILDER->precompile_address_info}) {
-      my $address_of_methods = $BUILDER->precompile_address_info->{$class_name};
-      for my $method_name (keys %$address_of_methods) {
-        my $address = $address_of_methods->{$method_name};
-        $BUILDER->set_precompile_method_address($class_name, $method_name, $address);
+      # Set precompile method addresses
+      for my $class_name (keys %{$builder->precompile_address_info}) {
+        my $address_of_methods = $builder->precompile_address_info->{$class_name};
+        for my $method_name (keys %$address_of_methods) {
+          my $address = $address_of_methods->{$method_name};
+          $builder->set_precompile_method_address($class_name, $method_name, $address);
+        }
       }
-    }
 
-    # Call INIT blocks
-    $BUILDER->call_init_blocks;
-    
-    # Set command line info
-    $BUILDER->set_command_info($0, \@ARGV);
-    
+      # Call INIT blocks
+      $builder->call_init_blocks;
+    }
     $SPVM_INITED = 1;
   }
 }
@@ -306,11 +294,6 @@ sub new_object_array {
   SPVM::ExchangeAPI::new_object_array($BUILDER, @_);
 }
 
-sub new_any_object_array {
-  SPVM::init() unless $SPVM_INITED;
-  SPVM::ExchangeAPI::new_any_object_array($BUILDER, @_);
-}
-
 sub new_mulnum_array {
   SPVM::init() unless $SPVM_INITED;
   SPVM::ExchangeAPI::new_mulnum_array($BUILDER, @_);
@@ -350,15 +333,15 @@ sub call_spvm_method {
 
 =encoding utf8
 
-=head1 Name
+=head1 NAME
 
 SPVM - SPVM Language
 
-=head1 Caution
+=head1 CAUTHION
 
-C<SPVM> is not yet 1.0 release. C<SPVM> is quit often changed without warnings until I feel the implementation is enough good.>
+B<C<SPVM> is not yet 1.0 release. C<SPVM> is quit often changed without warnings until I feel the implementation is enough good.>
 
-=head1 Usage
+=head1 SYNOPSIS
 
 Write a SPVM Module:
 
@@ -390,11 +373,11 @@ Call the SPVM method from Perl:
 
   print "$total\n";
 
-=head1 Description
+=head1 DESCRIPTION
 
 B<SPVM>(Static Perl Virtual Machine) is a perl-ish static typed programing language. SPVM provides fast calculation, fast array operations, easy C/C++ binding, and creating executable files.
 
-=head1 Document
+=head1 DOCUMENT
 
 SPVM documents.
 
@@ -414,7 +397,7 @@ SPVM Language Specification.
 
 =over 2
 
-=item * L<Language Specification|SPVM::Document::Language>
+=item * L<Language Specification|SPVM::Document::LanguageSpecification>
 
 =back
 
@@ -498,7 +481,7 @@ SPVM performance benchmarks.
 
 =back
 
-=head1 Environment Variables
+=head1 ENVIRONMENT VARIABLES
 
 =head2 SPVM_BUILD_DIR
 
@@ -520,27 +503,27 @@ Print debug messages of L<SPVM::Builder::CC> to stderr.
 
 Force the compilation and the link of L<SPVM::Builder::CC>.
 
-=head1 Repository
+=head1 REPOSITORY
 
 L<Github|https://github.com/yuki-kimoto/SPVM>
 
-=head1 Bug Report
+=head1 BUG REPORT
 
 L<GitHub Issue|https://github.com/yuki-kimoto/SPVM/issues>
 
-=head1 Support
+=head1 SUPPORT
 
 L<Github Discussions|https://github.com/yuki-kimoto/SPVM/discussions>
 
-=head1 Author
+=head1 AUTHOR
 
 Yuki Kimoto E<lt>kimoto.yuki@gmail.comE<gt>
 
-=head1 Core Developers
+=head1 CORE DEVELOPERS
 
 motiE<lt>motohiko.ave@gmail.comE<gt>
 
-=head1 Contributors
+=head1 CONTRIBUTORS
 
 =over 2
 
@@ -560,13 +543,9 @@ motiE<lt>motohiko.ave@gmail.comE<gt>
 
 =item * Suman Khanal
 
-=item * L<Ryunosuke Murakami|https://github.com/ryun0suke22>
-
-=item * L<Yoshiyuki Itoh|https://github.com/YoshiyukiItoh>
-
 =back
 
-=head1 Copyright & LICENSE
+=head1 COPYRIGHT & LICENSE
 
 Copyright 2018-2022 Yuki Kimoto, all rights reserved.
 
