@@ -1,8 +1,8 @@
-=head1 Name
+=head1 NAME
 
 SPVM::Document::NativeAPI - SPVM Native APIs
 
-=head1 Description
+=head1 DESCRIPTION
 
 The SPVM native APIs are public APIs that are used in native language sources such as C<C/C++>.
 
@@ -27,8 +27,8 @@ Native APIs have its IDs. These IDs are permanently same for the binary compatib
   10 allocator
   11 new_env_raw
   12 free_env_raw
-  13 isa
-  14 elem_isa
+  13 check_runtime_assignability
+  14 check_runtime_assignability_array_element
   15 runtime
   16 reserved16
   17 reserved17
@@ -197,19 +197,6 @@ Native APIs have its IDs. These IDs are permanently same for the binary compatib
   180 print_stderr
   181 init_env,
   182 call_init_blocks
-  183 get_class_id
-  184 new_stack
-  185 free_stack
-  186 get_instance_method_id_super
-  187 new_memory_env
-  188 free_memory_env
-  189 get_memory_blocks_count_env
-  190 new_memory_stack
-  191 free_memory_stack
-  192 get_memory_blocks_count_stack
-  193 set_command_info_program_name
-  194 set_command_info_argv
-  195 get_class_id_by_name
 
 =head2 class_vars_heap
 
@@ -308,15 +295,15 @@ Create a new raw envriment.
 
 Free the raw environemt that is created by L</"new_env_raw">.
 
-=head2 isa
+=head2 check_runtime_assignability
 
-  int32_t (*isa)(SPVM_ENV* env, SPVM_VALUE* stack, void* object, int32_t cast_basic_type_id, int32_t cast_type_dimension);
+  int32_t (*check_runtime_assignability)(SPVM_ENV* env, SPVM_VALUE* stack, int32_t cast_basic_type_id, int32_t cast_type_dimension, void* object);
 
-Perform C<isa> operation.
+Check the runtime type assignability of an object.
 
-=head2 elem_isa
+=head2 check_runtime_assignability_array_element
 
-  int32_t (*elem_isa)(SPVM_ENV* env, SPVM_VALUE* stack, void* array, void* element);
+  int32_t (*check_runtime_assignability_array_element)(SPVM_ENV* env, SPVM_VALUE* stack, void* array, void* element);
 
 Check the runtime type assignability of an array element.
 
@@ -1227,25 +1214,23 @@ Specifying the address of the object releases the weak reference to the object.
 
 =head2 alloc_memory_block_zero
 
-  void* (*alloc_memory_block_zero)(SPVM_ENV* env, size_t byte_size);
+  void* (*alloc_memory_block_zero)(SPVM_ENV* env, int64_t byte_size);
 
-Create a new memory block that is managed by the environment with the byte size and return the address. If it fails, return C<NULL>.
-
-The count of the memory block that is managed by the environment is incremented by C<1>.
+If you specify the size in bytes, the memory block is allocated and the pointer of the allocated memory block is returned. If fail to alloc memory, return NULL. If success, all bits in the memory block are initialized with C<0> and the memory block count (memory_blocks_count)is incremented by C<1>.
 
 =head2 free_memory_block
 
   void (*free_memory_block)(SPVM_ENV* env, void* block);
 
-Free the memory block that is managed by the environment.
-
-The count of the memory block that is managed by the environment is decremented by C<1>.
+If block is not NULL, free the memory and memory blocks count(memory_blocks_count) is decremented by C<1>.
 
 =head2 get_memory_blocks_count
 
   int32_t (*get_memory_blocks_count)(SPVM_ENV* env);
 
-Return the count of the memory blocks on the environment.
+Returns the current number of memory blocks of thie environment.
+
+The memory block is increased by 1 when an object is created, when the alloc_memory_block_zero function is called, and when a back reference is added by the weaken function.
 
 =head2 get_type_name_raw
 
@@ -2019,112 +2004,6 @@ Initialize the environment.
 
 Call C<INIT> blocks.
 
-=head2 get_class_id
-
-  int32_t (*get_class_id)(SPVM_ENV* env, const char* class_name);
-
-=head2 new_stack
-
-  SPVM_VALUE* (*new_stack)(SPVM_ENV* env);
-
-=head2 free_stack
-
-  void (*free_stack)(SPVM_ENV* env, SPVM_VALUE* stack);
-
-=head2 get_instance_method_id_super
-
-  int32_t (*get_instance_method_id_super)(SPVM_ENV* env, void* object, const char* method_name, const char* signature);
-
-=head2 new_memory_env
-
-  void* (*new_memory_env)(SPVM_ENV* env, size_t byte_size);
-
-Create a new memory block that is managed by the environment with the byte size and return the address. If it fails, return C<NULL>.
-
-The count of the memory block that is managed by the environment is incremented by C<1>.
-
-This is the same as L</"alloc_memory_block_zero">. This is more understandable name that memories are managed by the environment.
-
-=head2 free_memory_env
-
-  void (*free_memory_env)(SPVM_ENV* env, void* block);
-
-Free the memory block that is managed by the environment.
-
-The count of the memory block that is managed by the environment is decremented by C<1>.
-
-This is the same as L</"free_memory_block">. This is more understandable name that memories are managed by the environment.
-
-=head2 get_memory_blocks_count_env
-
-  int32_t (*get_memory_blocks_count_env)(SPVM_ENV* env);
-
-Return the count of the memory blocks on the environment.
-
-This is the same as L</"get_memory_blocks_count">. This is more understandable name that memories are managed by the environment.
-
-=head2 new_memory_stack
-
-  void* (*new_memory_stack)(SPVM_ENV* env, SPVM_VALUE* stack, size_t byte_size);
-
-Create a new memory block that is managed by the stack of the environment with the byte size and return the address. If it fails, return C<NULL>.
-
-The count of the memory block that is managed by the stack is incremented by C<1>.
-
-The count of the memory block that is managed by the environment is incremented by C<1>.
-
-=head2 free_memory_stack
-
-  void (*free_memory_stack)(SPVM_ENV* env, SPVM_VALUE* stack, void* block);
-
-Free the memory block that is managed by the environment.
-
-The count of the memory block that is managed by the stack is decremented by C<1>.
-
-The count of the memory block that is managed by the environment is decremented by C<1>.
-
-=head2 get_memory_blocks_count_stack
-
-  int32_t (*get_memory_blocks_count_stack)(SPVM_ENV* env, SPVM_VALUE* stack);
-
-Return the count of the memory blocks on the stack.
-
-=head2 set_command_info_program_name
-
-  int32_t (*set_command_info_program_name)(SPVM_ENV* env, SPVM_VALUE* stack, void* obj_program_name);
-
-Set the program name. This value is got by L<CommandInfo->PROGRAM_NAME|SPVM::CommandInfo/"PROGRAM_NAME">.
-
-If it succeed, return C<0>.
-
-The program name must be a C<string> object. Otherwise return non-zero value.
-
-=head2 set_command_info_argv
-
-  int32_t (*set_command_info_argv)(SPVM_ENV* env, SPVM_VALUE* stack, void* obj_argv);
-
-Set the argv. This value is got by L<CommandInfo->ARGV|SPVM::CommandInfo/"ARGV">.
-
-If it succeed, return C<0>.
-
-The argv must be a C<string[]> object. Otherwise return non-zero value.
-
-=head2 get_class_id_by_name
-
-  int32_t (*get_class_id_by_name)(SPVM_ENV* env, SPVM_VALUE* stack, const char* class_name, int32_t* error, const char* file, int32_t line);
-
-Get class id by the class name.
-
-If the class is not found, C<error> is set to C<1>. Otherwise set to C<0>.
-
-=head2 strerror
-
-  const char* (*strerror)(SPVM_ENV* env, SPVM_VALUE* stack, int32_t errno_value, int32_t length);
-
-Get the value of C<strerror> of C<C language> on thread-safely.
-
-If the length is C<0>, the length is set to C<64>.
-
 =head1 Compiler Native API
 
 L<SPVM::Document::NativeAPI::Compiler>
@@ -2147,7 +2026,7 @@ L<SPVM::Document::NativeAPI::Allocator>
 
 =head1 Constant Values
 
-=head2 Basic Type IDs
+=head2 Constant Values of Basic Type IDs
 
   0  SPVM_NATIVE_C_BASIC_TYPE_ID_UNKNOWN
   1  SPVM_NATIVE_C_BASIC_TYPE_ID_UNDEF
@@ -2160,15 +2039,13 @@ L<SPVM::Document::NativeAPI::Allocator>
   8  SPVM_NATIVE_C_BASIC_TYPE_ID_DOUBLE
   9  SPVM_NATIVE_C_BASIC_TYPE_ID_STRING
   10 SPVM_NATIVE_C_BASIC_TYPE_ID_ANY_OBJECT
-  11 SPVM_NATIVE_C_BASIC_TYPE_ID_BYTE_CLASS
-  12 SPVM_NATIVE_C_BASIC_TYPE_ID_SHORT_CLASS
-  13 SPVM_NATIVE_C_BASIC_TYPE_ID_INT_CLASS
-  14 SPVM_NATIVE_C_BASIC_TYPE_ID_LONG_CLASS
-  15 SPVM_NATIVE_C_BASIC_TYPE_ID_FLOAT_CLASS
-  16 SPVM_NATIVE_C_BASIC_TYPE_ID_DOUBLE_CLASS
-  17 SPVM_NATIVE_C_BASIC_TYPE_ID_BOOL_CLASS
-  18 SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_CLASS
-  19 SPVM_NATIVE_C_BASIC_TYPE_ID_COMMAND_INFO_CLASS
+  11 SPVM_NATIVE_C_BASIC_TYPE_ID_BYTE_OBJECT
+  12 SPVM_NATIVE_C_BASIC_TYPE_ID_SHORT_OBJECT
+  13 SPVM_NATIVE_C_BASIC_TYPE_ID_INT_OBJECT
+  14 SPVM_NATIVE_C_BASIC_TYPE_ID_LONG_OBJECT
+  15 SPVM_NATIVE_C_BASIC_TYPE_ID_FLOAT_OBJECT
+  16 SPVM_NATIVE_C_BASIC_TYPE_ID_DOUBLE_OBJECT
+  17 SPVM_NATIVE_C_BASIC_TYPE_ID_TYPE_CONVERSION_CONDITINAL_OBJECT
 
 These IDs are permanently same for the binary compatibility after the future release C<v1.0>.
 
@@ -2216,38 +2093,34 @@ The basic type ID of C<string> type.
 
 The basic type ID of C<object> type.
 
-=head3 SPVM_NATIVE_C_BASIC_TYPE_ID_BYTE_CLASS
+=head3 SPVM_NATIVE_C_BASIC_TYPE_ID_BYTE_OBJECT
 
 The basic type ID of L<Byte|SPVM::Byte> type.
 
-=head3 SPVM_NATIVE_C_BASIC_TYPE_ID_SHORT_CLASS
+=head3 SPVM_NATIVE_C_BASIC_TYPE_ID_SHORT_OBJECT
 
 The basic type ID of L<Short|SPVM::Short> type.
 
-=head3 SPVM_NATIVE_C_BASIC_TYPE_ID_INT_CLASS
+=head3 SPVM_NATIVE_C_BASIC_TYPE_ID_INT_OBJECT
 
 The basic type ID of L<Int|SPVM::Int> type.
 
-=head3 SPVM_NATIVE_C_BASIC_TYPE_ID_LONG_CLASS
+=head3 SPVM_NATIVE_C_BASIC_TYPE_ID_LONG_OBJECT
 
 The basic type ID of L<Long|SPVM::Long> type.
 
-=head3 SPVM_NATIVE_C_BASIC_TYPE_ID_FLOAT_CLASS
+=head3 SPVM_NATIVE_C_BASIC_TYPE_ID_FLOAT_OBJECT
 
 The basic type ID of L<Float|SPVM::Float> type.
 
-=head3 SPVM_NATIVE_C_BASIC_TYPE_ID_DOUBLE_CLASS
+=head3 SPVM_NATIVE_C_BASIC_TYPE_ID_DOUBLE_OBJECT
 
 The basic type ID of L<Double|SPVM::Double> type.
 
-=head3 SPVM_NATIVE_C_BASIC_TYPE_ID_BOOL_CLASS
+=head3 SPVM_NATIVE_C_BASIC_TYPE_ID_TYPE_CONVERSION_CONDITINAL_OBJECT
 
 The basic type ID of L<BOOL|SPVM::BOOL> type.
 
-=head3 SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_CLASS
-
-The basic type ID of L<Error|SPVM::Error> type.
-
 =head2 Constant Values of Basic Type Categories
 
   0 SPVM_NATIVE_C_BASIC_TYPE_CATEGORY_UNKNOWN
@@ -2303,33 +2176,6 @@ The basic type category for the interface types.
 
 The basic type category for the any object type.
 
-=head2 Class IDs
-
-  1  SPVM_NATIVE_C_CLASS_ID_ERROR
-
-These IDs are permanently same for the binary compatibility after the future release C<v1.0>.
-
-=head3 SPVM_NATIVE_C_CLASS_ID_ERROR
-
-The class id of L<Error|SPVM::Error> class.
-
-=head3 SPVM_NATIVE_C_BASIC_TYPE_ID_UNKNOWN
-
-The basic type is unknown.
-
-=head1 Utility Functions
-
-=head2 spvm_warn
-
-  void spvm_warn(const char* format, ...)
-
-Print the formatted message to C<stderr> with a new line.
-
-B<Examples:>
-
-  spvm_warn("Hello");
-  spvm_warn("Hello %s%d", "Foo", 3);
-
 =head1 Examples
 
 =over 2
